@@ -2,6 +2,8 @@
 
 for site in /etc/drupal/7/sites/* ; do
 	BASE_URL=""
+	CRON_KEY=""
+	FULL_URL=""
 
 	if [ ! "`basename $site`" = "all" ]; then
 		for file in $site/baseurl.php $site/settings.php; do
@@ -19,9 +21,17 @@ for site in /etc/drupal/7/sites/* ; do
 		fi
 
 		if [ "X$CRON_KEY" = "X" ] ; then
-			curl --fail --silent --compressed --location $BASE_URL/cron.php
+			FULL_URL="$BASE_URL/cron.php"
 		else
-			curl --fail --silent --compressed --location $BASE_URL/cron.php?cron_key=$CRON_KEY
+			FULL_URL="$BASE_URL/cron.php?cron_key=$CRON_KEY"
+		fi
+
+		if curl -S --fail --silent --compressed --location $FULL_URL ; then
+		        # Success!
+		        true
+		else
+		        echo "Error running the periodic maintenance for $site: CURL exit code $?"
+			echo "Requested URL: $FULL_URL"
 		fi
 	fi
 done
